==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pt_BR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "Linha"

, "Caller Id"
: "Id do Chamador"

, "Start"
: "Início"

, "Connected"
: "Conectado"

, "Disconnected"
: "Desconectado"

, "Duration"
: "Duração"

, "Ringing"
: "Tocando"

, "Direction"
: "Direção"

, "Source"
: "Fonte"

, "Destination"
: "Destino"

, "Phone"
: ""

, "Phones"
: "Telefones"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "Número"

, "Cancel"
: "Canelar"

, "Dial"
: "Discar"

, "Error"
: "Erro"

, "Not possible to dial."
: "Não é possível discar."

, "Edit phone settings"
: "Ediar configuração do telefone"

, "Dial number"
: "Discar número"

, "Initiate a new outgoing call"
: "Iniciar uma nova chamada"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: "Chamar contato"

, "Work"
: "Operar"

, "Home"
: "Início"

, "Cell"
: "Celular"

, "Cell private"
: "Celular particular"

, "Incoming call"
: "Recebendo chamada"

, "Outgoing call"
: "Chamando"

, "unknown number"
: "número desconhecido"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.03.4.tar.bz2: Phone/js/Phone-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Recebendo chamada"

, "Outgoing call"
: "Chamando"

, "unknown number"
: "número desconhecido"

, "Phone"
: ""

, "Line"
: "Linha"

, "Number"
: "Número"

, "Cancel"
: "Canelar"

, "Dial"
: "Discar"

, "Error"
: "Erro"

, "Not possible to dial."
: "Não é possível discar."

, "Call contact"
: "Chamar contato"

, "Work"
: "Operar"

, "Home"
: "Início"

, "Cell"
: "Celular"

, "Cell private"
: "Celular particular"

, "Edit phone settings"
: "Ediar configuração do telefone"

, "Dial number"
: "Discar número"

, "Initiate a new outgoing call"
: "Iniciar uma nova chamada"

, "Phones"
: "Telefones"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "Id do Chamador"

, "Start"
: "Início"

, "Connected"
: "Conectado"

, "Disconnected"
: "Desconectado"

, "Duration"
: "Duração"

, "Ringing"
: "Tocando"

, "Direction"
: "Direção"

, "Source"
: "Fonte"

, "Destination"
: "Destino"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
